@@ -70,49 +70,36 @@ class mgCal(hildondesktop.HomeItem):
         self.eb = gtk.EventBox()
         self.toolbar = gtk.Toolbar()
         self.eb.add(self.toolbar)
+
         self.toolbar.set_orientation(gtk.ORIENTATION_HORIZONTAL)
         self.toolbar.set_style(gtk.TOOLBAR_ICONS)
         self.toolbar.set_border_width(0)
         self.eb.modify_bg(gtk.STATE_NORMAL,gtk.gdk.Color(13000,13000,13000,0))
 
-        self.ti1 = gtk.ToolItem()
-        self.ti1.set_expand(True)
-        self.eb1 = gtk.EventBox()
-        self.eb1.set_visible_window(False)
-        self.eb1.connect("button_press_event",self._MoveUp)
-        self.r1 = gtk.Image()
-        self.r1.set_from_file(icon_path+"mgcal_up.png")
-        #self.r1h = gtk.Image()
-        #self.r1h.set_from_file(icon_path+"mgcal_up_hi.png")
-        self.eb1.add(self.r1)
-        self.ti1.add(self.eb1)
-        self.toolbar.insert(self.ti1,-1)
+        self.img = gtk.Image()
+        self.img.set_from_file(icon_path+"mgcal_up.png")
+        self.toolbar_item = gtk.ToolButton(self.img)
+        self.toolbar_item.set_expand(True)
+        self.toolbar_item.connect("clicked",self._MoveUp)
+        self.toolbar_item.show()
+        self.toolbar.insert(self.toolbar_item,-1)
 
-        self.ti2 = gtk.ToolItem()
-        self.ti2.set_expand(True)
-        self.eb2 = gtk.EventBox()
-        self.eb2.set_visible_window(False)
-        self.eb2.connect("button_press_event",self._Refresh)
-        self.r2 = gtk.Image()
-        self.r2.set_from_file(icon_path+"mgcal_refresh.png")
-        #self.r2h = gtk.Image()
-        #self.r2h.set_from_file(icon_path+"mgcal_refresh_hi.png")
-        self.eb2.add(self.r2)
-        self.ti2.add(self.eb2)
-        self.toolbar.insert(self.ti2,-1)
+        self.img = gtk.Image()
+        self.img.set_from_file(icon_path+"mgcal_refresh.png")
+        self.toolbar_item = gtk.ToolButton(self.img)
+        self.toolbar_item.set_expand(True)
+        self.toolbar_item.connect("clicked",self._Refresh)
+        self.toolbar_item.show()
+        self.toolbar.insert(self.toolbar_item,-1)
+
+        self.img = gtk.Image()
+        self.img.set_from_file(icon_path+"mgcal_down.png")
+        self.toolbar_item = gtk.ToolButton(self.img)
+        self.toolbar_item.set_expand(True)
+        self.toolbar_item.connect("clicked",self._MoveDn)
+        self.toolbar_item.show()
+        self.toolbar.insert(self.toolbar_item,-1)
 
-        self.ti3 = gtk.ToolItem()
-        self.ti3.set_expand(True)
-        self.eb3 = gtk.EventBox()
-        self.eb3.set_visible_window(False)
-        self.eb3.connect("button_press_event",self._MoveDn)
-        self.r3 = gtk.Image()
-        self.r3.set_from_file(icon_path+"mgcal_down.png")
-        #self.r3h = gtk.Image()
-        #self.r3h.set_from_file(icon_path+"mgcal_down_hi.png")
-        self.eb3.add(self.r3)
-        self.ti3.add(self.eb3)
-        self.toolbar.insert(self.ti3,-1)
         self.vbox.pack_start(self.eb,False,False,0)
 
         self.set_size_request(400,300)
